@@ -21,13 +21,13 @@
 #define ExportMailJob_H
 
 #include "abstractimportexportjob.h"
-#include "pimsettingexportercore_private_export.h"
+#include "pimdataexportercore_private_export.h"
 #include <KSharedConfig>
 #include <QDateTime>
 #include <time.h>
 class ArchiveStorage;
 
-class PIMSETTINGEXPORTER_TESTS_EXPORT ExportMailJob : public AbstractImportExportJob
+class PIMDATAEXPORTER_TESTS_EXPORT ExportMailJob : public AbstractImportExportJob
 {
     Q_OBJECT
 public:
